@@ -2,5 +2,6 @@ class ModelConfig:
     """
     Interaction class is used to store the model config to be used in the prompt engine
     """
-    def __init__(self, max_tokens):
-        self.max_tokens = max_tokens
\ No newline at end of file
+    def __init__(self, max_tokens, **kwargs):
+        self.max_tokens = max_tokens
+        self.__dict__.update(kwargs)
\ No newline at end of file
